# $Id: testing_io.py,v 1.1 2017/01/24 22:06:14 leavens Exp leavens $
# Author: Gary T. Leavens
# Some helpers for testing interactive I/O programs

import sys
def runtest(proc, prefix):
    """Run the 0-argument procedure proc with input from file '${prefix}.in'
    and output going to file '${prefix}.txt'."""
    # open the input and output files
    inf = open(prefix + ".in", "r")
    outf = open(prefix + ".txt", "w")
    try:
        # run the procedure proc with input from inf and output from outf
        runit(proc, inf, outf)
    finally:
        inf.close()
        outf.close()
    # read in the actual output and the expectd output
    readout = open(prefix + ".txt", "r")
    readexpected = open(prefix + ".expected", "r")
    try:
        readout_contents = readout.read()
        readexpected_contents = readexpected.read()
        # they should be the same
        assert readout_contents == readexpected_contents
    finally:
        readout.close()
        readexpected.close()

def runit(proc, inf, outf):
    """Run the 0-argument procedure proc with input from file inf
    (which acts as stdin)
    and output going to outf (which captures stdout)."""
    # save the standard streams in old...
    oldstdin = sys.stdin
    oldstdout = sys.stdout
    oldstderr = sys.stderr
    # replace the standard streams
    sys.stdin = inf
    sys.stdout = outf
    sys.stderr = outf
    try:
        proc()
    finally:
        # restore the standard streams
        sys.stdin = oldstdin
        sys.stdout = oldstdout
        sys.stderr = oldstderr
